
-- BIGX curse: replaces the current block with a big cross -------------------

ID_CURSE_BIGX=7

function bigx_do_curse(sent)
    if sent==0 then
        u61_send_curse(ID_CURSE_BIGX)
    else
        u61_clear_block()
        u61_add_item(0,0,7) 
        u61_add_item(-1,-1,7) 
        u61_add_item(-1,1,7) 
        u61_add_item(1,-1,7) 
        u61_add_item(1,1,7) 
        u61_add_item(-2,-2,7) 
        u61_add_item(-2,2,7) 
        u61_add_item(2,-2,7) 
        u61_add_item(2,2,7) 
    end
end

